pub enum Level {
Packet,
Connection,
Session,
}Expand description
The abstraction level of the subscribable type.
Variants
Packet
Suitable for analyzing individual packets or frames where connection-level semantics are unnecessary.
Connection
Suitable for analyzing entire connections, whether as a single record or a stream.
Session
Suitable for analyzing session-level data, of which there may be multiple instances per connection.